@@ -84,7 +84,7 @@ estVC.default <-
    if(!all(is.finite(y)))
       stop("y: non-numeric or infinite data points not allowed.")
    if(!missing(x))
-      if(any(is.infinite(x) | is.na(x)))
+      if(any(sapply(x,is.infinite) | sapply(x,is.na)))
          stop("x: missing or infinite data points not allowed.")
 
    if(!missing(x)){
@@ -96,13 +96,13 @@ estVC.default <-
    method<-  match.arg(method)
 
    estVC.4(y = y,
-            x = x,
-            v = v,
-            initpar = initpar,
-            nit = nit,
-            method = method,
-            control = control,
-            hessian = hessian)
+           x = x,
+           v = v,
+           initpar = initpar,
+           nit = nit,
+           method = method,
+           control = control,
+           hessian = hessian)
 }
 
 estVC.1 <-
