@@ -22,7 +22,7 @@ ibs.1<- function(prdat){
    nc<- dim(prdat)[3]
    npairs<- nr*(nr+1)/2
 
-   cat("  Please wait or press 'ctrl-c' to abort...\n")
+#   cat("  Please wait or press 'ctrl-c' to abort...\n")
    ibsc<- matrix(-1,nrow=npairs,ncol=9)
    out<- .C("ibsPrc",
             prdat=as.double(aperm(prdat, c(3,2,1))),
@@ -64,12 +64,12 @@ ibs.2<- function(gdat){
               (gdata=="AB")*2 +
               (gdata=="BB")*3
    if(any(!is.element(unique(c(gdata)),c(1,2,3))))
-      stop("gdat: wrong input...")
+      stop("gdat: wrong genotye input...")
    nr<- nrow(gdata)
    nc<- ncol(gdata)
    npairs<- nr*(nr+1)/2
 
-   cat("  Please wait or press 'ctrl-c' to abort...\n")
+#   cat("  Please wait or press 'ctrl-c' to abort...\n")
    ibsc<- matrix(-1,nrow=npairs,ncol=9)
    out<- .C("ibsFnc",
             gdat=as.integer(t(gdata)),
@@ -122,7 +122,7 @@ genMatrix.default<- function(x){
    nc<- ncol(gdata)
    npairs<- nr*(nr+1)/2
 
-   cat("  Please wait or press 'ctrl-c' to abort...\n")
+#   cat("  Please wait or press 'ctrl-c' to abort...\n")
    deltac<- matrix(-1,nrow=npairs,ncol=5)
    out<- .C("deltaFnc",
             x=as.integer(t(gdata)),
